/*
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string.h>

#include <gtk/gtk.h>
#include <libxfce4util/libxfce4util.h>

#include "libappstarter/as.h"

#define PLUGIN "firefox"

gchar *cmd;
gchar *url;
guint  with_uri = 0;

gchar *
get_cmd()
{
    if (with_uri)
        cmd = g_strconcat (PLUGIN, " ", url, NULL);
    else
        cmd = PLUGIN;
    return cmd;
}

static void
save_config()
{
    XfceRc *rc;

    rc = as_rc_open(FALSE);
    if (!rc)
        return;
    xfce_rc_set_group(rc, PLUGIN);
    xfce_rc_write_entry(rc, "url", url);
    xfce_rc_write_int_entry(rc, "withuri", with_uri);
    xfce_rc_close(rc);
}

static void
read_config()
{
    XfceRc *rc;

    rc = as_rc_open (TRUE);
    if (!rc)
        return;

    xfce_rc_set_group(rc, PLUGIN);
    url = strdup (xfce_rc_read_entry (rc, "url", ""));
    with_uri = xfce_rc_read_int_entry (rc, "withuri", 0);

    xfce_rc_close(rc);
}

static void
entry_changed(GtkWidget *fe, gpointer *data)
{
    url = strdup (as_file_entry_get_filename (AS_FILE_ENTRY (fe)));
    save_config();
}

static void
chk_toggled(GtkWidget *chk, gpointer *data)
{
    GtkWidget *fe = (GtkWidget *) data;

    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (chk)))
    {
        with_uri = 1;
        gtk_widget_set_sensitive (fe, TRUE);
    } else {
        with_uri = 0;
        gtk_widget_set_sensitive (fe, FALSE);
    }
    save_config();
}

GtkWidget *
get_config_widget()
{
    GtkWidget *hbox, *chk;
    GtkWidget *fe;

    read_config ();

    hbox = gtk_hbox_new (FALSE, 2);
    chk = gtk_check_button_new_with_label (
        _("Start with this URL or file: "));
    gtk_box_pack_start (GTK_BOX (hbox), chk, FALSE, FALSE, 2);
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chk),
        with_uri ? TRUE : FALSE);
    gtk_widget_show (chk);

    fe = as_file_entry_new(_("Select a file"),
        GTK_FILE_CHOOSER_ACTION_OPEN, url);
    if (!with_uri)
        gtk_widget_set_sensitive (fe, FALSE);
    gtk_box_pack_start (GTK_BOX (hbox), fe, TRUE, TRUE, 2);

    g_signal_connect (G_OBJECT (fe), "changed",
        G_CALLBACK (entry_changed), NULL);
    g_signal_connect (G_OBJECT (chk), "toggled",
        G_CALLBACK (chk_toggled), (gpointer) fe);

    return hbox;
}

void
free_all()
{
    g_free(cmd);
    g_free(url);
}
